package database

import (
	"context"
	"database/sql"

	"git.anthrove.art/Anthrove/otter-space-sdk/v2/pkg/models"
)

type OtterSpace interface {
	// Connect establishes a connection to the database.
	Connect(ctx context.Context, config models.DatabaseConfig) error

	// Post contains all function that are needed to manage Posts
	Post

	// User contains all function that are needed to manage the AnthroveUser
	User

	// Source contains all function that are needed to manage the Source
	Source

	// Tag contains all functions that are used to manage Tag
	Tag

	// TagAlias contains all function that are needed to manage the TagAlias
	TagAlias

	// TagGroup contains all function that are needed to manage the TagGroup
	TagGroup

	// ExecuteRawStatement run a custom query.
	ExecuteRawStatement(ctx context.Context, query string, args ...any) (*sql.Rows, error)
}
